@@ -154,7 +154,7 @@ Date: {date}
         return data
 
 
-class ImageCollection(Dataset):
+class   ImageCollection(Dataset):
     INFO = """ID: {id}
 Start Date: {start_date}
 End Date: {end_date}
@@ -252,13 +252,23 @@ Visualizers: {visualizers}
                 ee.Algorithms.If(unbounded, col, col.filterBounds(bounds)))
 
         if isinstance(date, (list, tuple)):
-            col = col.filterDate(ee.Date(date[0]), ee.Date(date[1]))
+            if len(date) == 2:
+                start = date[0]
+                end = date[1]
+            else:
+                start = date[0]
+                end = None
+            if start and end:
+                col = col.filterDate(ee.Date(start), ee.Date(end))
+            elif start:
+                col = col.filterDate(ee.Date(start))
+            elif end:
+                col = col.filterDate('1970-01-01', ee.Date(start))
         elif isinstance(date, (str, ee.Date)):
             col = col.filterDate(ee.Date(date))
 
         if shortname_prop:
             col = col.map(lambda i: i.set(shortname_prop, self.short_name))
-
         return col
 
     def getMask(self, name):
@@ -497,23 +507,28 @@ Visualizers: {visualizers}
             final = final.select(bands)
         return final
 
-    def normalization_table(self, renamed=False):
+    def normalization_table(self, bands='all', renamed=False):
         """ Get a ee.Dictionary holding the normalization parameters in form of
         {'band': {'scale': xx, 'offset': xx}, 'band2':....}
         """
         local = {}
+        if isinstance(bands, str):
+            bands = bands.lower()
         for band in self.bands:
-            if renamed:
-                name = band.alias
+            b = band.alias if renamed else band.name
+            if b in bands or bands == 'all':
+                scale = band.scale
+                offset = band.offset
             else:
-                name = band.name
-            local[name] = {'scale': band.scale, 'offset': band.offset}
+                scale = 1
+                offset = 0
+            local[b] = {'scale': scale, 'offset': offset}
         return ee.Dictionary(local)
 
-    def normalize(self, image, renamed=False):
+    def normalize(self, image, bands='all', renamed=False):
         """ Multiply by scale and shift offset to get values between 0 and 1
         """
-        data = self.normalization_table(renamed)
+        data = self.normalization_table(bands, renamed)
         bands = image.bandNames()
         def overbands(band, i):
             i = ee.Image(i)
